@@ -189,7 +189,7 @@ function initNewInfoStore() {
 		// implement api prefill
 		populateForm(null, url);
 		
-		if (url['attachmail'] && url['attachmail'] > 0) {
+		if (url['attachmail']) {
 			oMailInfo = { mailid: url['mailid'], mailfolder: url['mailfolder'], attachmail: url['attachmail'] };
 			
 		} else if (url['attachmodule'] && url['attid'] > 0 && url['attobjid'] > 0 && url['attobjfolder'] > 0) {
