@@ -349,11 +349,24 @@ var toggleImipTab = function(button, what) {
 
 function initMessageContent(loadblockedimages) {
 	var oNestedMessage = ox.api.window.getData(url.guid).oNestedMessage;
-	if (oNestedMessage && oNestedMessage.length) {
-		message.id = oNestedMessage[0].id;
-		message.folder_id = message.folder_id || url["folder"];
-		oNestedMessage[0].folder_id = message.folder_id;
-		drawMessage(oNestedMessage[0], message.folder_id);
+    if (oNestedMessage && oNestedMessage.length) {
+        var msg = oNestedMessage[0];
+        message.id = msg.id;
+        message.folder_id = message.folder_id || url.folder;
+        msg.folder_id = message.folder_id;
+        if (msg.attachments) return drawMessage(msg, message.folder_id);
+        ox.api.http.GET({
+            module: "mail",
+            params: {
+                action: "attachment",
+                folder: message.folder_id,
+                id: url.id,
+                attachment: msg.id,
+                // special parameter to get the json data from a nested mail
+                as_json: true
+            },
+            success: function (data) { drawMessage(data, message.folder_id); }
+        });
 	} else {
 		message.id = url["id"];
 		message.folder_id = url["folder"];
@@ -649,32 +662,24 @@ function setMessageText(message) {
 				(function(oDOMDiv, selNested_msgs) {
 					var wrapper = function(e) {
                 		selectAttachment({ node: oDOMDiv, data: selNested_msgs.length ? selNested_msgs[0] : selNested_msgs}, (Mac ? e.metaKey : e.ctrlKey), false);
-                		detailNestedMessage = selNested_msgs;
-						if (!detailNestedMessage.sid) 
-							detailNestedMessage.sid = !isNaN(url["sid"]) ? url["sid"] + nMessage : nMessage;
+                        detailNestedMessage = selNested_msgs;
                 	};
                     addDOMEvent(oDOMDiv, "click", wrapper);
                     addDOMEvent(oDOMDiv, "contextmenu", function(e) {
                         stopEvent(e);
                         selectAttachment({ node: oDOMDiv, data: selNested_msgs.length ? selNested_msgs[0] : selNested_msgs}, false, true);
                         detailNestedMessage = selNested_msgs;
-                        if (!detailNestedMessage.sid) 
-                            detailNestedMessage.sid = !isNaN(url["sid"]) ? url["sid"] + nMessage : nMessage;
                         globalContextMenus.attachments.display(e.clientX,
                                                                e.clientY);
                     });
 					addDOMEvent(oDOMDiv, "dblclick", function(e) {
 						cancelBubbling(e);							
 						detailNestedMessage = selNested_msgs;
-						if (!detailNestedMessage.sid) 
-							detailNestedMessage.sid = !isNaN(url["sid"]) ? url["sid"] + nMessage : nMessage;
 						openNestedMessage();	
 					});
 					if (menucountsubselected == 0) {
                     	selectAttachment({ node: oDOMDiv, data: selNested_msgs.length ? selNested_msgs[0] : selNested_msgs}, false, false);
-                    	detailNestedMessage = selNested_msgs;
-                    	if (!detailNestedMessage.sid) 
-							detailNestedMessage.sid = !isNaN(url["sid"]) ? url["sid"] + nMessage : nMessage;
+                        detailNestedMessage = selNested_msgs;
 						menucountsubselected=1;
                     }
 				})(oDOMDiv, oNestedMessage);
@@ -826,26 +831,12 @@ function openNestedMessage() {
         params: {
             id: url.id,
             folder: url.folder,
-            sid: detailNestedMessage.sid,
             type: "isNestedMessage"
         },
 		data: {
             oNestedMessage: detailNestedMessage
         }
     });
-	
-	
-	/*
-	var detailMail=corewindow.newWindow("detailMail.html#type=isNestedMessage&id="
-		+ encodeURIComponent(url["id"])
-		+ "&folder="+ encodeURIComponent(url["folder"])
-		+ "&sid=" + encodeURIComponent(detailNestedMessage.sid), getWindowOptions(), 
-		{ "folder": encodeURIComponent(url["folder"]), "id": encodeURIComponent(detailNestedMessage.sid) });
-	detailMail.window.oNestedMessage = detailNestedMessage;
-	detailMail.oNestedMessage = detailNestedMessage;
-	if (detailMail) {
-		detailMail.focus();
-	}*/
 }
 
 function openAttachment(action) {	
