@@ -1646,27 +1646,23 @@ var setMailHeaderLabel;
                             var wrapper = function(e) {
                                 selectAttachment({ node: oDOMDiv, data: selNested_msgs.length ? selNested_msgs[0] : selNested_msgs, msg: true }, (Mac ? e.metaKey : e.ctrlKey), false);
                                 detailNestedMessage = selNested_msgs;
-                                detailNestedMessage.sid = o;
                             };
                             addDOMEvent(oDOMDiv, "click", wrapper);
                             addDOMEvent(oDOMDiv, "contextmenu", function(e) {
                                 stopEvent(e);
                                 selectAttachment({ node: oDOMDiv, data: selNested_msgs.length ? selNested_msgs[0] : selNested_msgs, msg: true }, false, true);
                                 detailNestedMessage = selNested_msgs;
-                                detailNestedMessage.sid = o;
                                 globalContextMenus.attachments.display(e.clientX,
                                                                        e.clientY);
                             });
                             addDOMEvent(oDOMDiv, "dblclick", function(e) {
                                 cancelBubbling(e);
                                 detailNestedMessage = selNested_msgs;
-                                detailNestedMessage.sid = o;
                                 openNestedMessage();
                             });
                             if (menucountsubselected == 0) {
                                 selectAttachment({ node: oDOMDiv, data: selNested_msgs.length ? selNested_msgs[0] : selNested_msgs, msg: true}, false, false);
                                 detailNestedMessage = selNested_msgs;
-                                detailNestedMessage.sid = o;
                                 menucountsubselected=1;
                             }
                         })(oDOMDiv, oNestedMessage);
@@ -1913,7 +1909,6 @@ var setMailHeaderLabel;
                 type: "isNestedMessage",
                 id: message.id,
                 folder: message.folder || message.folder_id,
-                sid: detailNestedMessage.sid
             },
             data: {
                 oNestedMessage: detailNestedMessage
